package com.unis.safety.server.controller.safety;

import com.unis.common.utils.DateUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.safety.common.vo.safety.AccidentVO;
import com.unis.safety.server.service.AccidentService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import java.io.OutputStream;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

/**
 * Author liugd
 *  事故管理
 */
@RestController
@RequestMapping(value = "/accident")
@Api(value = "事故管理", tags = "事故管理")
public class AccidentController {
   
    @Autowired
    private AccidentService accidentService;

 	//事故管理-新增
 	@ApiOperation(value = "事故管理-新增", notes = "参数：AccidentVO")
    @PostMapping(value = "/insertAccident")
    public ResponseWrapper insertAccident(@RequestBody  AccidentVO vo) {
		try {
			return accidentService.insertAccident(vo);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	//事故管理-修改
 	@ApiOperation(value = "事故管理-修改", notes = "参数：AccidentVO")
    @PostMapping(value = "/updateAccident")
    public ResponseWrapper updateAccident(@RequestBody AccidentVO vo) {
		try {
			return accidentService.updateAccident(vo);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	//事故管理-修改
	@ApiOperation(value = "事故管理-删除", notes = "参数：AccidentVO")
	@PostMapping(value = "/deleteAccident")
	public ResponseWrapper deleteAccident(@RequestBody AccidentVO vo) {
		try {
			return accidentService.deleteAccident(vo);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	//事故管理-分页列表
	@ApiOperation(value = "事故管理-分页列表", notes = "参数：AccidentVO")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
        @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })	
    @PostMapping(value = "/selectAccidentPageList")
    public ResponseWrapper selectAccidentPageList(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum
        ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
        ,@RequestBody AccidentVO vo) {
       	try {
			return accidentService.selectAccidentPageList(pageNum,pageSize,vo);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
    }
    
 /*   //事故管理-列表全部数据
    @ApiOperation(value = "事故管理-列表全部数据", notes = "参数：AccidentVO")
    @PostMapping(value = "/selectAccidentAll")
    public ResponseWrapper selectAccidentAll(@RequestBody AccidentVO vo) {
       	try {
			return accidentService.selectAccidentAll(vo);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
    }*/

	//事故管理-查看--返回单条
	@ApiOperation(value = "事故管理--查看--返回单条", notes = "参数：AccidentVO")
	@PostMapping(value = "/selectAccidentDetail")	
    public ResponseWrapper selectAccidentDetail(@RequestBody AccidentVO vo) {
       	try {
			return accidentService.selectAccidentDetail(vo);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
    }
	
	
	   //安全事故统计报表
		@ApiOperation(value = "安全事故统计报表", notes = "安全事故统计报表")
	    @ApiImplicitParams({
	        @ApiImplicitParam(name = "createDate", value = "年份", dataType = "int", paramType = "query")
	    })	
	    @PostMapping(value = "/selectAccidentStatement")
	    public ResponseWrapper selectAccidentStatement(@RequestParam(value = "createDate") String createDate
	        ) {
	       	try {
				return accidentService.selectAccidentStatement(createDate);
			} catch (Exception e) {
				e.printStackTrace();
				return ResponseWrapper.error();
			}
	    }
		
		
		@ApiOperation(value = "安全事故统计表-根据条件导出数据", notes = "安全事故统计表")
	    @ApiImplicitParams({
	            @ApiImplicitParam(name = "createDate", value = "年 例如：2023", paramType = "query")
	    })
	    @RequestMapping(value="/exportByEntity",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	    public void exportByEntity(HttpServletRequest request, HttpServletResponse response
	            ,String createDate) throws Exception {
	            
			
			HSSFWorkbook wb = accidentService.exportByEntity(createDate);
			
			 //导出
	        String fileName = createDate+"年安全事故统计表";

	        try {
	            fileName = new String(fileName.getBytes("UTF-8"), "ISO-8859-1");
	            //response.setHeader("Content-disposition", "attachment;filename=\"" + fileName + "\"");
	            response.setHeader("content-disposition", "attachment;filename="
	       				+ new String(DateUtil.getDate()) + ".xls");
	            response.setContentType("application/vnd.ms-excel;charset=gb2312");
	            OutputStream stream = response.getOutputStream();
	            if (null != wb && null != stream) {
	                wb.write(stream);// 将数据写出去  
	                wb.close();
	                stream.close();
	            }
	        } catch (Exception e) {
	            e.printStackTrace();
	        }
	    
	    }
		
}
