package com.unis.safety.server.controller.safety;

import com.unis.common.utils.ResponseWrapper;
import com.unis.safety.common.vo.safety.DutyVO;
import com.unis.safety.server.service.DutyService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * Author liugd
 *  值班安排
 */
@RestController
@RequestMapping(value = "/duty")
@Api(value = "值班安排", tags = "值班安排")
public class DutyController {
   
    @Autowired
    private DutyService dutyService;

 	//值班安排-新增
 	@ApiOperation(value = "值班安排-新增", notes = "参数：DutyVO")
    @PostMapping(value = "/insertDuty")
    public ResponseWrapper insertDuty(@RequestBody  DutyVO vo) {
		try {
			return dutyService.insertDuty(vo);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	//值班安排-修改
 	@ApiOperation(value = "值班安排-修改", notes = "参数：DutyVO")
    @PostMapping(value = "/updateDuty")
    public ResponseWrapper updateDuty(@RequestBody DutyVO vo) {
		try {
			return dutyService.updateDuty(vo);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	//值班安排-分页列表
	@ApiOperation(value = "值班安排-分页列表", notes = "参数：DutyVO")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
        @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })	
    @PostMapping(value = "/selectDutyPageList")
    public ResponseWrapper selectDutyPageList(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum
        ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
        ,@RequestBody DutyVO vo) {
       	try {
			return dutyService.selectDutyPageList(pageNum,pageSize,vo);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
    }
    
 /*   //值班安排-列表全部数据
    @ApiOperation(value = "值班安排-列表全部数据", notes = "参数：DutyVO")
    @PostMapping(value = "/selectDutyAll")
    public ResponseWrapper selectDutyAll(@RequestBody DutyVO vo) {
       	try {
			return dutyService.selectDutyAll(vo);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
    }*/

	//值班安排-查看--返回单条
	@ApiOperation(value = "值班安排--查看--返回单条", notes = "参数：DutyVO")
	@PostMapping(value = "/selectDutyDetail/{id}")
    public ResponseWrapper selectDutyDetail(@PathVariable("id") String id) {
       	try {
			return dutyService.selectDutyDetail(id);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
    }

	//事故管理-查看--返回单条
	@ApiOperation(value = "事故管理--查看--返回单条", notes = "参数：AccidentVO")
	@PostMapping(value = "/selectDutyByDetail")
	public ResponseWrapper selectDutyByDetail(@RequestBody DutyVO vo) {
		try {
			return dutyService.selectDutyByDetail(vo);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}
	@ApiOperation(value = "事故管理--催办", notes = "参数：DutyVO")
	@PostMapping(value = "/selectToDo")
	public ResponseWrapper selectToDo(@RequestBody DutyVO vo) {
		try {
			return dutyService.selectToDo(vo);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}
	//值班安排-查看--返回单条
	@ApiOperation(value = "值班安排--查看--返回单条", notes = "参数：DutyVO")
	@GetMapping(value = "/isDuty")
	public ResponseWrapper isDuty(@RequestParam String jhsj) {
		try {
			return dutyService.isDuty(jhsj);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	//值班安排-查看--返回单条
	@ApiOperation(value = "值班安排-判断当前月区粮办下属企业是否添加值班", notes = "参数：DutyVO")
	@PostMapping(value = "/isAddDuty")
	public ResponseWrapper isAddDuty(@RequestParam String qyxx) {
		try {
			return dutyService.isAddDuty(qyxx);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}
}
