package com.unis.safety.server.controller.safety;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.safety.common.vo.safety.ProdSystemVo;
import com.unis.safety.server.service.ProdSystemService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

/**
 * @author by PIG
 * @date 2022/3/16 10
 */
@Slf4j
@Api(value = "安全生产制度", tags = "安全生产制度")
@RestController
@RequestMapping("/prod_system")
public class ProdSystemController {

    @Autowired
    private ProdSystemService prodSystemService;

    @ApiOperation(value = "分页查询安全生产制度信息", notes = "")
    @PostMapping(value = "/page_info/{pageNum}/{pageSize}")
    public ResponseWrapper pageInfo(@RequestBody ProdSystemVo viewObj,
                                    @PathVariable("pageNum")Integer pageNum,
                                    @PathVariable("pageSize") Integer pageSize){
        try {
            PageInfo<ProdSystemVo> pageInfos = prodSystemService.pageInfo(viewObj, pageNum, pageSize);
            return ResponseWrapper.success(pageInfos);
        } catch (Exception e) {
            log.error(e.getMessage());
            e.printStackTrace();
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"查询信息失败",null);
    }

    @ApiOperation(value = "查询安全生产制度信息详情", notes = "")
    @GetMapping(value = "/info/{fid}")
    public ResponseWrapper getInfo(@PathVariable("fid") String fid){
        try {
            ProdSystemVo r = prodSystemService.getInfoById(fid);
            return ResponseWrapper.success(r);
        } catch (Exception e) {
            log.error(e.getMessage());
            e.printStackTrace();
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"查询信息失败",null);
    }

    @ApiOperation(value = "新增安全生产制度信息", notes = "")
    @PostMapping(value = "/info")
    public ResponseWrapper insertInfo(@RequestBody ProdSystemVo viewObj){
        try {
            int r = prodSystemService.insertInfo(viewObj);
            return ResponseWrapper.success("新增成功");
        } catch (Exception e) {
            log.error(e.getMessage());
            e.printStackTrace();
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"插入信息失败",null);
    }

    @ApiOperation(value = "修改安全生产制度信息", notes = "")
    @PutMapping(value = "/info")
    public ResponseWrapper updateInfo(@RequestBody ProdSystemVo viewObj){
        try {
            int r = prodSystemService.updateInfo(viewObj);
            return ResponseWrapper.success(HttpStatus.OK.value(),"更新成功",null);
        } catch (Exception e) {
            log.error(e.getMessage());
            e.printStackTrace();
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"更新信息失败",null);
    }

    @ApiOperation(value = "删除安全生产制度信息", notes = "逻辑删除")
    @PutMapping(value = "/info/{fid}")
    public ResponseWrapper removeInfo(@PathVariable("fid") String fid){
        try {
            int r = prodSystemService.removeInfo(fid);
            return ResponseWrapper.success(HttpStatus.OK.value(),"新增成功",null);
        } catch (Exception e) {
            log.error(e.getMessage());
            e.printStackTrace();
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"删除信息失败",null);
    }
    @ApiOperation(value = "删除安全生产制度信息", notes = "物理删除")
    @DeleteMapping(value = "/info/{fid}")
    public ResponseWrapper deleteInfo(@PathVariable("fid") String fid){
        try {
            int r = prodSystemService.deleteInfo(fid);
            return ResponseWrapper.success(HttpStatus.OK.value(),"删除成功 " + r,null);
        } catch (Exception e) {
            log.error(e.getMessage());
            e.printStackTrace();
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"删除信息失败",null);
    }

}
