package com.unis.safety.server.domain.safety;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.safety.common.constant.SafeConstant;
import com.unis.safety.common.utils.EntityUtil;
import com.unis.safety.common.vo.safety.AccidentRecordVO;
import com.unis.safety.common.vo.safety.AccidentVO;
import com.unis.safety.server.dao.AccidentDao;
import com.unis.safety.server.dao.AccidentRecordDao;
import com.unis.safety.server.entity.safety.AccidentDO;
import com.unis.safety.server.entity.safety.AccidentRecordDO;
import com.unis.safety.server.entity.safety.AccidentStatementDO;
import com.unis.safety.server.service.impl.BaseRepository;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 事故管理
 * @author liugd
 */
@Component
public class AccidentDomain {

    @Autowired
    AccidentDao accidentDao;
    @Autowired
    AccidentRecordDao accidentRecordDao;

    @Autowired
    BaseRepository baseMapper;
    /**
     * 通用的插入处理Calendar.getInstance().get(Calendar.YEAR)
     * @param entity <保证金退款>
     */
    private void buildInsertData(AccidentDO entity){
        entity.buildInsertData();
        String pk= baseMapper.selectByTableNameAndAttr(EntityUtil.getTableName(AccidentDO.class)
                ,"acbm", "AC", 8);
        entity.setAcbm(pk);
    }

    /**
     * 通用的更新处理
     * @param entity
     */
    private void buildUpdateData(AccidentDO entity){
        entity.buildUpdateData();
    }

    public ResponseWrapper insertAccident(AccidentVO vo) {
        AccidentDO entity= JsonUtils.parse(
                JsonUtils.serialize(vo),AccidentDO.class);
        buildInsertData(entity);
        if("LS001".equals(CurrentUtil.getOrgId())){
            entity.setCkzt(SafeConstant.KCK.getValue());
        }else{
            if(SafeConstant.YTJ.getValue().equals(entity.getSbzt())){
                entity.setCkzt(SafeConstant.KCK.getValue());
            }
        }
        int num = accidentDao.insertSelective(entity);
        if(SafeConstant.YTJ.getValue().equals(entity.getSbzt())){
            AccidentRecordDO accidentRecordDO =  new AccidentRecordDO();
            accidentRecordDO.setAcbm(entity.getAcbm());
            accidentRecordDO.setClqk(entity.getClqk());
            accidentRecordDO.setFsyy(entity.getFsyy());
            accidentRecordDO.setSgdj(entity.getSgdj());
            accidentRecordDO.setSgdjmc(entity.getSgdjmc());
            accidentRecordDO.setSsnum(entity.getSsnum());
            accidentRecordDO.setSwnum(entity.getSwnum());
            accidentRecordDO.setSsqk(entity.getSsqk());
            accidentRecordDO.setXgsj(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
            accidentRecordDao.insert(accidentRecordDO);
        }
        return ResponseWrapper.choose(num);
    }

    public ResponseWrapper updateAccident(AccidentVO vo) {
        AccidentDO entity= JsonUtils.parse(
                JsonUtils.serialize(vo),AccidentDO.class);
        //判断数据是否有改变
        if(SafeConstant.YTJ.getValue().equals(entity.getSbzt())){
            if(changeData(vo)){
                AccidentRecordDO accidentRecordDO =  new AccidentRecordDO();
                accidentRecordDO.setAcbm(entity.getAcbm());
                accidentRecordDO.setClqk(entity.getClqk());
                accidentRecordDO.setFsyy(entity.getFsyy());
                accidentRecordDO.setSgdj(entity.getSgdj());
                accidentRecordDO.setSgdjmc(entity.getSgdjmc());
                accidentRecordDO.setSsnum(entity.getSsnum());
                accidentRecordDO.setSwnum(entity.getSwnum());
                accidentRecordDO.setSsqk(entity.getSsqk());
                accidentRecordDO.setXgsj(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
                accidentRecordDao.insert(accidentRecordDO);
            }
        }
        buildUpdateData(entity);
        if("LS001".equals(CurrentUtil.getOrgId())){
            entity.setCkzt(SafeConstant.KCK.getValue());
        }else{
            if(SafeConstant.YTJ.getValue().equals(entity.getSbzt())){
                entity.setCkzt(SafeConstant.KCK.getValue());
            }
        }
        int num = accidentDao.updateByPrimaryKeySelective(entity);
        return ResponseWrapper.choose(num);
    }
    public boolean changeData(AccidentVO vo){
        boolean res = false;
        AccidentDO accidentDO = accidentDao.selectByPrimaryKey(vo.getAcbm());
        if(!accidentDO.getSgdjmc().equals(vo.getSgdjmc())){
            return true;
        }
        if(!accidentDO.getSsqk().equals(vo.getSsqk())){
            return true;
        }
        if(!accidentDO.getSsnum().equals(vo.getSsnum())){
            return true;
        }
        if(!accidentDO.getSwnum().equals(vo.getSwnum())){
            return true;
        }
        if(!accidentDO.getFsyy().equals(vo.getFsyy())){
            return true;
        }
        /*if(!accidentDO.getClqk().equals(vo.getClqk())){
            return true;
        }*/
        return res;
    }

    public ResponseWrapper selectAccidentDetail(AccidentVO vo) {
        AccidentDO selectById = accidentDao.selectByPrimaryKey(vo.getAcbm());
        List<AccidentRecordVO> list = accidentDao.selectByAcbm(selectById.getAcbm());
        AccidentVO entity= JsonUtils.parse(
                JsonUtils.serialize(selectById),AccidentVO.class);
        entity.setAccidentRecordVOList(list);
        return ResponseWrapper.success(entity);
    }


    public Page<AccidentVO> selectAccidentPageList(int pageNum, int pageSize, AccidentVO vo) {
        PageHelper.startPage(pageNum,pageSize);
        if(StringUtils.isBlank(vo.getSbdw())){
            if("LS001".equals(CurrentUtil.getOrgId())){
                vo.setCkzt(SafeConstant.KCK.getValue());
            }else{
                vo.setSbdw(CurrentUtil.getOrgId());
            }
        }
        Page<AccidentVO> selectPageList = accidentDao.selectPageList(vo);
        return selectPageList;
    }

    public ResponseWrapper deleteAccident(AccidentVO vo) {
        int num = accidentDao.deleteByPrimaryKey(vo.getAcbm());
        return ResponseWrapper.choose(num);
    }

	public List<AccidentStatementDO> selectAccidentStatement(Map<String, Object> map1) {
		// TODO Auto-generated method stub
		return accidentDao.selectAccidentStatement(map1);
	}

	public List<AccidentStatementDO> selectQymc(Map<String, Object> map1) {
		// TODO Auto-generated method stub
		return accidentDao.selectQymc(map1);
	}

	/*public List<AccidentStatementDO> selectAccidentStatement(int createDate) {
		// TODO Auto-generated method stub
		return accidentDao.selectAccidentStatement(createDate);
	}*/
}
