package com.unis.safety.server.domain.safety;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.safety.common.utils.EntityUtil;
import com.unis.safety.common.vo.backlog.BacklogAddVO;
import com.unis.safety.common.vo.backlog.ReceiverCollectionVO;
import com.unis.safety.common.vo.safety.DutyRecordVO;
import com.unis.safety.common.vo.safety.DutyVO;
import com.unis.safety.server.dao.DutyDao;
import com.unis.safety.server.dao.DutyRecordDao;
import com.unis.safety.server.entity.safety.DutyDO;
import com.unis.safety.server.entity.safety.DutyRecordDO;
import com.unis.safety.server.service.BacklogMQService;
import com.unis.safety.server.service.impl.BaseRepository;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * 事故管理
 * @author liugd
 */
@Component
public class DutyDomain {

    @Autowired
    DutyDao dutyDao;
    @Autowired
    DutyRecordDao dutyRecordDao;
    @Autowired
    BacklogMQService mqService;

    @Autowired
    BaseRepository baseMapper;
    /**
     * 通用的插入处理Calendar.getInstance().get(Calendar.YEAR)
     */
    private void buildInsertData(DutyDO entity){
        entity.buildInsertData();
        String pk= baseMapper.selectByTableNameAndAttr(EntityUtil.getTableName(DutyDO.class)
                ,"dybm", "DY", 8);
        entity.setDybm(pk);
    }

    /**
     * 通用的更新处理
     * @param entity
     */
    private void buildUpdateData(DutyDO entity){
        entity.buildUpdateData();
    }

    public ResponseWrapper insertDuty(DutyVO vo) {
        DutyDO entity= JsonUtils.parse(
                JsonUtils.serialize(vo),DutyDO.class);
        buildInsertData(entity);
        //填写上级单位以便查询
        if("LS001".equals(CurrentUtil.getOrgId())){
            entity.setSjdj("0");
        }else{
            //判断是不是区粮办单位  10180007 区粮办
            if("10180007".equals(CurrentUtil.getOrgLevel())){
                entity.setSjdj("1");
            }else{
                entity.setSjdwbm(CurrentUtil.getSslsxzglbm());
                entity.setJlzt("0");
                entity.setSjdj("2");
            }
        }
        int num = dutyDao.insertSelective(entity);
        if(vo.getRecords()!=null&&vo.getRecords().length()>0) {
            String dataJson = vo.getRecords();
            if (dataJson != null) {
                List<DutyRecordDO> voList = JsonUtils.parseList(JsonUtils.serialize(dataJson), DutyRecordDO.class);
                for(DutyRecordDO recordDO:voList){
                    recordDO.setDybm(entity.getDybm());
                    dutyRecordDao.insertSelective(recordDO);
                }
            }
            }
        return ResponseWrapper.choose(num);
    }

    public ResponseWrapper updateDuty(DutyVO vo) {
        DutyDO entity= JsonUtils.parse(
                JsonUtils.serialize(vo),DutyDO.class);
        buildUpdateData(entity);
        //填写上级单位以便查询
        if("LS001".equals(CurrentUtil.getOrgId())){
        }else{
            //判断是不是区粮办单位  10180007 区粮办
            if("10180007".equals(CurrentUtil.getOrgLevel())){
            }else{
                entity.setSjdwbm(CurrentUtil.getSslsxzglbm());
            }
        }
        int num = dutyDao.updateByPrimaryKeySelective(entity);
        //先删除
        dutyDao.deleteByDybm(vo.getDybm());
        if(vo.getRecords()!=null&&vo.getRecords().length()>0) {
            String dataJson = vo.getRecords();
            if (dataJson != null) {
                List<DutyRecordDO> voList = JsonUtils.parseList(JsonUtils.serialize(dataJson), DutyRecordDO.class);
                for(DutyRecordDO recordDO:voList){
                    recordDO.setDybm(entity.getDybm());
                    dutyRecordDao.insert(recordDO);
                }
            }
        }
        return ResponseWrapper.choose(num);
    }


    public ResponseWrapper selectDutyDetail(String id) {
        DutyDO selectById = dutyDao.selectByPrimaryKey(id);
        List<DutyRecordVO> list = dutyDao.selectByDybm(id);
        DutyVO entity= JsonUtils.parse(
                JsonUtils.serialize(selectById),DutyVO.class);
        entity.setDutyRecordVOS(list);
        return ResponseWrapper.success(entity);
    }


    public Page<DutyVO> selectDutyPageList(int pageNum, int pageSize, DutyVO vo) {
        PageHelper.startPage(pageNum,pageSize);
        Page<DutyVO> selectPageList = null;
        if("LS001".equals(CurrentUtil.getOrgId())){
            if("LS001".equals(vo.getDwbm())&&vo.getDwbm()!=null){
                selectPageList = dutyDao.selectPageList(vo);
            }else if(!"LS001".equals(vo.getDwbm())&&vo.getDwbm()!=null&&!"".equals(vo.getDwbm())){
                //selectPageList = dutyDao.selectPageListSb(vo);
                selectPageList = dutyDao.selectPageList(vo);
            }else{
                selectPageList = dutyDao.selectPageListSb(vo);
            }
        }else if("10180007".equals(CurrentUtil.getOrgLevel())){
            if("".equals(vo.getDwbm())){
                vo.setDwbm(CurrentUtil.getOrgId());
            }
            selectPageList = dutyDao.selectPageListQlb(vo);
        }else{
            selectPageList  = dutyDao.selectPageLists(vo);
        }
        return selectPageList;
    }
    public ResponseWrapper isDuty(String jhsj) {
        boolean res = true;
        DutyVO dutyVO = dutyDao.findDuty(jhsj,CurrentUtil.getOrgId());
        if(dutyVO!=null){
            res = false;
        }
        return ResponseWrapper.success(res);
    }

    public ResponseWrapper selectDutyByDetail(DutyVO vo) {
        DutyVO dutyVO = dutyDao.selectDutyByDetail(vo);
        if(dutyVO!=null){
            List<DutyRecordVO> list = dutyDao.selectByDybm(dutyVO.getDybm());
            dutyVO.setDutyRecordVOS(list);
        }
        return ResponseWrapper.success(dutyVO);
    }

    public ResponseWrapper isAddDuty(String qyxx) {
        boolean res = true;
        //当前年月
        //if("10180007".equals(CurrentUtil.getOrgLevel())){
        String jhsj = DateUtil.DateToStr(new Date(),"yyyy-MM");
     /*   String[] sj = jhsj.split("-");
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM");
        Calendar calendar = Calendar.getInstance();
        try {
            calendar.setTime(sdf.parse(jhsj));
        }catch (Exception e){

        }*/
        //int num = calendar.getActualMaximum(Calendar.DAY_OF_MONTH);
        if(StringUtils.isNotBlank(qyxx)){
            String[] data = qyxx.split(",");
            for(String str:data){
                DutyVO vo = new DutyVO();
                vo.setJhsj(jhsj);
                vo.setDwbm(str.split("-")[0]);
                DutyVO dutyVO = dutyDao.selectDutyByDetail(vo);
                if(dutyVO!=null){
                }else{
                    DutyDO dutyDO = new DutyDO();
                    dutyDO.setJhsj(jhsj);
                    dutyDO.setJlzt("0");
                    dutyDO.setDwbm(str.split("-")[0]);
                    dutyDO.setDwmc(str.split("-")[1]);
                    dutyDO.setSjdwbm(CurrentUtil.getOrgId());
                    if("10180007".equals(CurrentUtil.getOrgLevel())){
                        dutyDO.setSjdj("2");
                    }else {
                        dutyDO.setSjdj("1");
                    }
                    dutyDO.setCkzt("0");
                    dutyDO.setSbzt("0");
                    buildInsertData(dutyDO);
                    dutyDao.insertSelective(dutyDO);
                 /*   for(int i=1;i<num+1;i++){
                        DutyRecordDO dutyRecordVO = new DutyRecordDO();
                        if(i>9){
                            dutyRecordVO.setRq(sj[0]+"."+sj[1]+"."+i);
                        }else{
                            dutyRecordVO.setRq(sj[0]+"."+sj[1]+"."+"0"+i);
                        }
                        dutyRecordVO.setDybm(dutyDO.getDybm());
                        dutyRecordVO.setSign("1");
                        dutyRecordDao.insertSelective(dutyRecordVO);
                    }*/
                }
            }
        }
       // }
        return ResponseWrapper.success(res);
    }

    public ResponseWrapper selectToDo(DutyVO vo) {
        DutyDO dutyDO = dutyDao.selectByPrimaryKey(vo.getDybm());
        dutyDO.setJlzt("1");
        dutyDao.updateByPrimaryKeySelective(dutyDO);
            System.out.println("*************进入创建待办************");
            BacklogAddVO record = new BacklogAddVO();
            record.buildAddVO(record);
            record.setItemQuery(dutyDO.getDybm());
            record.setItemType("提醒");
            //多次提醒还是一次提醒
            record.setItemQueryHaveDone(vo.getItemQueryHaveDone());
            record.setItemUrlHaveDone(vo.getItemUrlHaveDone());
            record.setItemId(dutyDO.getDybm());
            record.setItemName(dutyDO.getJhsj() + "月的值班安排需要填写上报");
            record.setItemStatus(0);
            record.setItemStatusName("待提交");
            record.setItemUrl(vo.getUrl());
            // 另起线程执行待办
            // ThreadUtil.startThread(record,vo.getUserList());
            new Thread(new Runnable() {
                @Override
                public void run() {
                    for (ReceiverCollectionVO userVO : vo.getUserList()) {
                        System.out.println("********************接收人*******************");
                        System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
                        System.out.println("********************************************");
                        record.setReceiver(userVO.getUserName());
                        record.setReceiverId(userVO.getUserId());
                        // 需要将对象序列化成JSONObject
                        mqService.sendMsg(JSON.parseObject(com.unis.safety.common.utils.JsonUtils.serialize(record)), "insert");
                    }
                }
            }).start();

        return ResponseWrapper.success("催办发送成功");
    }
}
