package com.unis.safety.server.domain.safety;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.safety.common.utils.EntityUtil;
import com.unis.safety.common.vo.safety.TrainingVO;
import com.unis.safety.server.dao.TrainingDao;
import com.unis.safety.server.dao.TrainingRecordDao;
import com.unis.safety.server.entity.safety.TrainingDO;
import com.unis.safety.server.service.impl.BaseRepository;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 事故管理
 * @author liugd
 */
@Component
public class TrainingDomain {

    @Autowired
    TrainingDao trainingDao;
    @Autowired
    TrainingRecordDao trainingRecordDao;

    @Autowired
    BaseRepository baseMapper;
    /**
     * 通用的插入处理Calendar.getInstance().get(Calendar.YEAR)
     */
    private void buildInsertData(TrainingDO entity){
        entity.buildInsertData();
        String pk= baseMapper.selectByTableNameAndAttr(EntityUtil.getTableName(TrainingDO.class)
                ,"pxbm", "PX", 8);
        entity.setPxbm(pk);
    }

    /**
     * 通用的更新处理
     * @param entity
     */
    private void buildUpdateData(TrainingDO entity){
        entity.buildUpdateData();
    }

    public ResponseWrapper insertTraining(TrainingVO vo){
        TrainingDO entity= JsonUtils.parse(
                JsonUtils.serialize(vo),TrainingDO.class);
        buildInsertData(entity);
        entity.setCjdw(","+entity.getCjdw()+",");
        if(entity.getQlbbm()!=null){
            entity.setQlbbm(","+entity.getQlbbm()+",");
        }
        if("1".equals(entity.getTjzt())){
            try {
                SimpleDateFormat dateFormat=new SimpleDateFormat("yyyy-MM-dd HH");
                Date nows=new java.util.Date();
                Date date=dateFormat.parse(vo.getPxsj());
                boolean hous=nows.getTime()>=date.getTime();
                if(hous){
                    entity.setPxzt("1");
                }
            }catch (Exception e){
                e.printStackTrace();
            }

        }
        int num = trainingDao.insertSelective(entity);
        return ResponseWrapper.choose(num);
    }

    public ResponseWrapper updateTraining(TrainingVO vo){
        TrainingDO entity= JsonUtils.parse(
                JsonUtils.serialize(vo),TrainingDO.class);
        buildUpdateData(entity);
        entity.setCjdw(","+entity.getCjdw()+",");
        if(entity.getQlbbm()!=null){
            entity.setQlbbm(","+entity.getQlbbm()+",");
        }
        if("1".equals(entity.getTjzt())){
            try {
                SimpleDateFormat dateFormat=new SimpleDateFormat("yyyy-MM-dd HH");
                Date nows=new java.util.Date();
                Date date=dateFormat.parse(vo.getPxsj());
                boolean hous=nows.getTime()>=date.getTime();
                if(hous){
                    entity.setPxzt("1");
                }
            }catch (Exception e){
                e.printStackTrace();
            }

        }
        int num = trainingDao.updateByPrimaryKeySelective(entity);
        return ResponseWrapper.choose(num);
    }

    public ResponseWrapper selectTrainingDetail(String id) {
        TrainingDO selectById = trainingDao.selectByPrimaryKey(id);
        TrainingVO entity= JsonUtils.parse(
                JsonUtils.serialize(selectById),TrainingVO.class);
        if(entity.getQlbbm()!=null){
            entity.setQlbbm(entity.getQlbbm().substring(1,entity.getQlbbm().length()-1));
        }
        entity.setCjdw(entity.getCjdw().substring(1,entity.getCjdw().length()-1));
        return ResponseWrapper.success(entity);
    }


    public Page<TrainingVO> selectTrainingPageList(int pageNum, int pageSize, TrainingVO vo) {
        PageHelper.startPage(pageNum,pageSize);
        String fqdw = "";
        if(StringUtils.isNotBlank(vo.getFqdw())){
            fqdw = vo.getFqdw();
        }
        if("10180007".equals(CurrentUtil.getOrgLevel())){
            vo.setQlbbm(","+CurrentUtil.getOrgId()+",");
        }
        //
        if("LS001".equals(CurrentUtil.getOrgId())||"LS001019".equals(CurrentUtil.getOrgId())||"LS001020".equals(CurrentUtil.getOrgId())||"LS001021".equals
                (CurrentUtil.getOrgId())){
            vo.setCjdw(","+CurrentUtil.getDeptId()+",");
        }
        Page<TrainingVO> selectPageList = null;
        if("LS001".equals(CurrentUtil.getOrgId())){
            vo.setFqdw(CurrentUtil.getDeptId());
            selectPageList = trainingDao.selectPageList(vo);
            if(StringUtils.isNotBlank(fqdw)){
                List<TrainingVO> list = new ArrayList<>();
                for(TrainingVO trainingVO:selectPageList.getResult()){
                    if(!trainingVO.getFqdw().equals(fqdw)){
                        list.add(trainingVO);
                    }
                }
                selectPageList.removeAll(list);
            }
        }else{
            selectPageList = trainingDao.selectPageLists(vo);
        }
        return selectPageList;
    }

    public ResponseWrapper deleteTraining(String id) {
        int num = trainingDao.deleteByPrimaryKey(id);
        return ResponseWrapper.choose(num);
    }

    public List<TrainingVO> selectTrainingList(String date) {
         return trainingDao.selectTrainingList(date);
    }

    public void updateTrain(TrainingVO trainingVO) {
        TrainingDO entity= trainingDao.selectByPrimaryKey(trainingVO.getPxbm());
        entity.setPxzt(trainingVO.getPxzt());
        int num = trainingDao.updateByPrimaryKeySelective(entity);
    }
}
